@@ -1,13 +1,13 @@
 package Regexp::Pattern::Perl::Release;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-27'; # DATE
-our $DIST = 'Regexp-Pattern-Perl'; # DIST
-our $VERSION = '0.006'; # VERSION
-
 use strict;
 #use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-07-30'; # DATE
+our $DIST = 'Regexp-Pattern-Perl'; # DIST
+our $VERSION = '0.007'; # VERSION
+
 our %RE = (
     perl_release_archive_filename => {
         summary => 'Proper filename of a typical distribution release archive (tarball/zip)',
@@ -40,7 +40,7 @@ Regexp::Pattern::Perl::Release - Regexp patterns related to Perl release
 
 =head1 VERSION
 
-This document describes version 0.006 of Regexp::Pattern::Perl::Release (from Perl distribution Regexp-Pattern-Perl), released on 2021-07-27.
+This document describes version 0.007 of Regexp::Pattern::Perl::Release (from Perl distribution Regexp-Pattern-Perl), released on 2022-07-30.
 
 =head1 SYNOPSIS
 
@@ -57,8 +57,6 @@ L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
 
 =item * perl_release_archive_filename
 
-Tags: capturing
-
 Proper filename of a typical distribution release archive (tarballE<sol>zip).
 
 Examples:
@@ -93,14 +91,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Regexp-Pat
 
 Source repository is at L<https://github.com/perlancar/perl-Regexp-Pattern-Perl>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Regexp-Pattern-Perl>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Other C<Regexp::Pattern::Perl::*> modules.
@@ -113,11 +103,36 @@ Some utilities related to Regexp::Pattern: L<App::RegexpPatternUtils>, L<rpgrep>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Regexp-Pattern-Perl>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
